AppStartBloc<S> class

应用启动状态管理器。

基于 StreamController 实现状态分发,零第三方依赖。 通过 stream 监听状态变化,通过 state 获取当前状态。

启动流程:

AppStarting → AppLoadDone → AppStartSuccess
                   ↓
             AppStartFailed

Constructors

AppStartBloc({required AppStartRepository<S> repository, required AppStartAction<S> startAction, int minStartDurationMs = 600})

Properties

hashCode int
The hash code for this object.
no setterinherited
minStartDurationMs int
final
repository AppStartRepository<S>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startAction AppStartAction<S>
final
state AppStatus
no setter
stream Stream<AppStatus>
no setter

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startApp() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited